<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://archive.org/embed/dn2015-0220_vid" width="640" height="480" style="border:none" frameborder="0" allowTransparency="true"></iframe>',
        'width' => 640,
        'height' => 480,
        'ratio' => 75.0
    ],
    'description' => 'Democracy Now! television program for Friday, February 20, 2015 Headlines for February 20, 2015 An Unsolved Case of Racial Terror: FBI Probes 1946...',
    'favicon' => 'https://archive.org/images/glogo.jpg',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://archive.org/download/dn2015-0220_vid/dn2015-0220_vid.thumbs/dn2015-0220_000090.jpg',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Internet Archive',
    'providerUrl' => 'https://archive.org',
    'publishedTime' => '2015-02-20 00:00:00',
    'redirect' => null,
    'title' => 'Democracy Now! Friday, February 20, 2015',
    'url' => 'https://archive.org/details/dn2015-0220_vid',
    'linkedData' => [
        '@context' => 'http://schema.org',
        '@type' => 'BreadcrumbList',
        'itemListElement' => [
            [
                '@type' => 'ListItem',
                'position' => 1,
                'item' => [
                    '@id' => 'https://archive.org/details/movies',
                    'name' => 'Videos',
                    'image' => 'https://archive.org/services/img/movies'
                ]
            ]
        ]
    ],
    'oEmbed' => [],
    'api' => [
        'server' => 'ia802600.us.archive.org',
        'dir' => '/20/items/dn2015-0220_vid',
        'metadata' => [
            'identifier' => [
                'dn2015-0220_vid'
            ],
            'addeddate' => [
                '2015-02-20 00:00:00'
            ],
            'mediatype' => [
                'movies'
            ],
            'title' => [
                'Democracy Now! Friday, February 20, 2015'
            ],
            'date' => [
                '2015-02-20'
            ],
            'year' => [
                '2015'
            ],
            'taper' => [
                'DN Studios'
            ],
            'source' => [
                'Television broadcast'
            ],
            'categories' => [
                'Democracy Now'
            ],
            'subject' => [
                'Democracy Now'
            ],
            'description' => [
                'Democracy Now! television program for Friday, February 20, 2015

<ul class="recent_shows"><li><a href="http://www.democracynow.org/2015/2/20/headlines" rel="nofollow">Headlines for February 20, 2015</a></li>
    <li><a href="http://www.democracynow.org/2015/2/20/an_unsolved_case_of_racial_terror" rel="nofollow">An Unsolved Case of Racial Terror: <span class="caps">FBI</span> Probes 1946 Moore’s Ford Bridge Lynching in Georgia</a></li>
    <li><a href="http://www.democracynow.org/2015/2/20/malcolm_x_remembered_50_years_after" rel="nofollow">Malcolm X Remembered 50 Years After 1965 Assassination</a></li>
    <li><a href="http://www.democracynow.org/2015/2/20/nsa_british_gchq_hacked_sim_card" rel="nofollow"><span class="caps">NSA</span> & British <span class="caps">GCHQ</span> Hacked <span class="caps">SIM</span> Card Maker to Steal Encryption Keys to Spy on Billions of Cellphones</a></li>
</ul>'
            ],
            'language' => [
                'en'
            ],
            'publicdate' => [
                '2015-02-20 00:00:00'
            ],
            'runtime' => [
                '59:02'
            ],
            'color' => [
                'color'
            ],
            'sound' => [
                'sound'
            ],
            'closed_captioning' => [
                'no'
            ],
            'collection' => [
                'democracy_now_vid',
                'newsandpublicaffairs'
            ],
            'backup_location' => [
                'ia905301_14'
            ],
            'ia_orig__runtime' => [
                '59 minutes 2 seconds'
            ]
        ],
        'files' => [
            '/__ia_thumb.jpg' => [
                'source' => 'original',
                'mtime' => '1539126011',
                'size' => '4660',
                'md5' => 'a7fdf9c9841c7d4438c0ecef58cbfb2e',
                'crc32' => '21b396c7',
                'sha1' => '69627aef4c817f4901f8437058ca67655c5acf8d',
                'format' => 'Item Tile',
                'rotation' => '0'
            ],
            '/dn2015-0220.gif' => [
                'source' => 'derivative',
                'format' => 'Animated GIF',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424450976',
                'size' => '368631',
                'md5' => 'c45300918d2ca43827595efe8890de65',
                'crc32' => '69a0751e',
                'sha1' => '9b938921aaee6aba39d21aa70c7e86448a01efb2'
            ],
            '/dn2015-0220.mp4' => [
                'source' => 'derivative',
                'format' => 'h.264',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424480294',
                'size' => '368442433',
                'md5' => '9883358631c40ef48f8538053add8474',
                'crc32' => '6beadd45',
                'sha1' => 'd5de45141922982e3ec5936e7fa14de3ef21f458',
                'length' => '3542.04',
                'height' => '480',
                'width' => '640'
            ],
            '/dn2015-0220.mpeg' => [
                'source' => 'original',
                'mtime' => '1424441271',
                'size' => '3028289536',
                'md5' => '1c25765e8d3031adcc65ba07ee354a66',
                'crc32' => 'e2600afc',
                'sha1' => 'cc2a820aa7be18ce96586d467756af42860f39dc',
                'format' => 'MPEG2',
                'length' => '3542.02',
                'height' => '480',
                'width' => '640'
            ],
            '/dn2015-0220.mpeg.idx' => [
                'source' => 'derivative',
                'format' => 'Video Index',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451020',
                'size' => '2934751',
                'md5' => '6f021022e197873cecb0ff06b2e71bfe',
                'crc32' => 'c8129a20',
                'sha1' => '343fd4ab097a54a3fc30a4a03fb98ba53a57ea4d'
            ],
            '/dn2015-0220.ogv' => [
                'source' => 'derivative',
                'format' => 'Ogg Video',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424488111',
                'size' => '267227655',
                'md5' => '7e19542e5587e380f7a00d71d742ee4b',
                'crc32' => '106921ba',
                'sha1' => '09159069195a61815f59fb276dd81e5b32d3e925',
                'length' => '3542.02',
                'height' => '300',
                'width' => '400'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000001.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451046',
                'size' => '6144',
                'md5' => '66f6e3657aceecce5082fc1b8e1c36b7',
                'crc32' => 'c2935285',
                'sha1' => '63287b509a45f20f31856acbf773d30f72f882b1'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000090.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451072',
                'size' => '4434',
                'md5' => '2989bf9f4634fd132f6cd21c738e130c',
                'crc32' => 'f8f9860c',
                'sha1' => '6bbeed2f963fcbf8f1361d10ec2e1c8472b93f0a'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000150.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451097',
                'size' => '6543',
                'md5' => 'ba120fba0fed088eb4ca1cc1299dc1b1',
                'crc32' => 'cc52d87d',
                'sha1' => '595ab0dc0d66e1f232c813ce0962d1ea1b6a0efb'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000210.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451122',
                'size' => '6142',
                'md5' => 'fd4d00547ccbea14c6f5b4e1e0b0b1d0',
                'crc32' => '46b6e4e5',
                'sha1' => '3b0e1907338454d550078e4a0b265fbf90165c1c'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000270.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451145',
                'size' => '8106',
                'md5' => '94d26c882a7fbed256f7668a228d50b1',
                'crc32' => 'ce04759e',
                'sha1' => '3872cf21383a47e9f90f99b4e05e5c187cd9ddf8'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000330.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451182',
                'size' => '6041',
                'md5' => 'ab9978595612c454bb6fb50c99d7b384',
                'crc32' => 'f51f2c25',
                'sha1' => '0ed45452a4dcb750277d669aabfef2711d1b74ae'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000390.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451205',
                'size' => '7273',
                'md5' => 'bd0d136f2edbac5298d21bde5ed9415b',
                'crc32' => 'e2139fe3',
                'sha1' => 'd0c3d604c336d89a325f64aa9f9b9303e656ba89'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000450.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451229',
                'size' => '5864',
                'md5' => '2da03fea59bc7fabf9e90f33c82909e0',
                'crc32' => '1fab040a',
                'sha1' => '3af5ec7c26428eb647c71052dc79072af1bd2ebb'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000510.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451253',
                'size' => '5872',
                'md5' => 'b9f043538546af668aec570ecc084a95',
                'crc32' => '8353be38',
                'sha1' => '159140d40b69abcdb89024482ba2b238d7f9b171'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000570.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451272',
                'size' => '5433',
                'md5' => '33d7f013bdd73ce47ee6ad47b953fcf7',
                'crc32' => '7884738b',
                'sha1' => 'b3ff9c16a11d3eeaa7096fd41e281175b0b1dda4'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000630.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451290',
                'size' => '5230',
                'md5' => 'de790b055419bd283dcaddd7300b6cc3',
                'crc32' => 'a792d351',
                'sha1' => 'efa379cf9ef3323ead1c16d4c4c116993418c34b'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000690.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451308',
                'size' => '5795',
                'md5' => 'c626e4a15c4ffa14bff283ace91b634f',
                'crc32' => '1e36c8e9',
                'sha1' => '36179a1a90c3d607368649a8279636ff60def686'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000750.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451332',
                'size' => '6502',
                'md5' => 'abce241ddd7f761b626d8df2f04f4196',
                'crc32' => '04ee4fee',
                'sha1' => '3c81ddba2166e6cfd4c5befd8b03a39a38f4421d'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000810.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451356',
                'size' => '3823',
                'md5' => 'e0adbe7a20cbb5f4a2be949c511d192d',
                'crc32' => 'f40aa1f3',
                'sha1' => 'f091115a7c3f0bb7c8056f0ac05e47084b3ecd94'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000870.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451382',
                'size' => '4863',
                'md5' => '0dd6763254ada56546cab158926da844',
                'crc32' => '040ea0cd',
                'sha1' => 'a663772ad6f4c67b7f17cf57706a637173849a1f'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000930.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451405',
                'size' => '5944',
                'md5' => '5b98fca01603821b3ce7a735a4443ba7',
                'crc32' => 'c4b57192',
                'sha1' => '5ed33e1bc7d5cb3666fe056b963fb3640db8cb74'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_000990.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451428',
                'size' => '5692',
                'md5' => 'd9a94f4303bf6a7b20eacd695ae71b20',
                'crc32' => 'c074c598',
                'sha1' => 'cf1537e36f56fdca8a658872876ae91b9938cc19'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001050.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451451',
                'size' => '5633',
                'md5' => '2ee5fa0c457ed4ec5cc74f40359d4645',
                'crc32' => '4a94e488',
                'sha1' => '4acc460f6c3d5123204b0dddd1f6992717e3ea80'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001110.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451466',
                'size' => '8020',
                'md5' => '11070bb90df260ec13c149cac2b6d35d',
                'crc32' => '46304160',
                'sha1' => 'aafe4d8eaca8c87ef937899388d61e5eb0671393'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001170.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451491',
                'size' => '4849',
                'md5' => 'e6e9da95ed8faff66e4516d604609f00',
                'crc32' => '1b4cd468',
                'sha1' => '9836ab4e8809bc857798175cd28d3ddbfc78cf9b'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001230.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451512',
                'size' => '8041',
                'md5' => 'd9bb2bb534355c2d3e37321fc33aed0a',
                'crc32' => 'ee651b82',
                'sha1' => '17a6284c78475d2ca9d7e5d9e2593ee97a3b186f'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001290.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451535',
                'size' => '7143',
                'md5' => 'df5926b2679ce504e15e2d2cf3edc8b8',
                'crc32' => 'd0f450ab',
                'sha1' => 'aa76a10bde421a447674e737076cb1404a4aa6f3'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001350.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451564',
                'size' => '7853',
                'md5' => '53f1c301cee93ba7f4d571658e67fb66',
                'crc32' => '37998263',
                'sha1' => '425cf1b918a077107b13c020d16082ac269bbb29'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001410.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451588',
                'size' => '4584',
                'md5' => '793069d70a58abf7d45d8b70fb6ee25b',
                'crc32' => 'ed5b104d',
                'sha1' => '84dfecff477557831039188914bcf548665b24e4'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001470.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451611',
                'size' => '8896',
                'md5' => '4c919cb8b5c9370c05cf48a5217fcbe9',
                'crc32' => 'b3f97a9c',
                'sha1' => 'd8da38fe6fdbd4e9c21ed314c69dd0f422d135ad'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001530.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451637',
                'size' => '4964',
                'md5' => 'df17c9a76d68e1074ec5b46d87211c70',
                'crc32' => '6ef97a80',
                'sha1' => 'ded26b656d9031e530aa4d96e0f4138649c31520'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001590.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451655',
                'size' => '5314',
                'md5' => 'bc66effb8aa421aeda194e5f6908f9d9',
                'crc32' => '41d7620c',
                'sha1' => '371a67db8d9197b852f43d383415a28bdf462530'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001650.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451681',
                'size' => '3528',
                'md5' => '6fb7687b42c1ec31af34810ea9c3828c',
                'crc32' => '7c441ec7',
                'sha1' => '87d2710cf9d391e4471b3d650c4f690bd3bd1ea9'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001710.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451705',
                'size' => '4889',
                'md5' => '16ab6e2714dd5d69757baff23f1bb687',
                'crc32' => '2937ad0e',
                'sha1' => '454cf1a8838985bb1e6edb4c876dd170609b8eea'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001770.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451726',
                'size' => '5956',
                'md5' => '8103bdb32a9f8e1f476b202df2d07381',
                'crc32' => '5ebf18f0',
                'sha1' => 'a03e7a70f2410e783616f0ffafe3b2cf4ae59eb3'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001830.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451749',
                'size' => '4030',
                'md5' => 'ecefe0c4cd7fb85d9eeb8f4394a44925',
                'crc32' => '7bc14197',
                'sha1' => 'ad2038e59cd3ec46757184a4ad69d964a48bb146'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001890.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451772',
                'size' => '3927',
                'md5' => '75f1b80c95a3af685aa7804bea77b956',
                'crc32' => '8b3a7e6c',
                'sha1' => '890a75d1a07f64b9f49a1da6650d6cfb9ce01c51'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_001950.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451797',
                'size' => '4160',
                'md5' => '279de49dd35fe2bd1d4112eceb638abd',
                'crc32' => '38c76305',
                'sha1' => 'ca38dbd7b8e790f87f70f2a986039057f753150f'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002010.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451825',
                'size' => '4756',
                'md5' => '9452951d8ce3d4a6f6a3ac6f2780ec01',
                'crc32' => 'f7e0766f',
                'sha1' => '809949c25e2c657349bba307ae408859eb213517'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002070.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451850',
                'size' => '7077',
                'md5' => '07a51b68c6be2319b8f4d91ece4bce3f',
                'crc32' => '467fd0d9',
                'sha1' => 'af27b1e6832d55dd6f3d8ff79b2a69707266bfd2'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002130.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451874',
                'size' => '7078',
                'md5' => 'a91b91effe56969cca263445a479eb0f',
                'crc32' => '8c8215d7',
                'sha1' => '89359a449f5930cab6056cbed2ac0f00bc86a210'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002190.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451897',
                'size' => '4934',
                'md5' => '855468ec5b258af349a39ed8ba6de326',
                'crc32' => '6546e4f6',
                'sha1' => 'bc9501a0d03a1680d49701c93ef3460b17c2c95f'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002250.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451937',
                'size' => '8913',
                'md5' => 'ac1a5af7261163e45ebffc5261ba80d3',
                'crc32' => 'b74c7561',
                'sha1' => '019bba015cda5282b8fa2726a3e4e969ad8a12ed'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002310.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424451971',
                'size' => '7797',
                'md5' => '081c5cd887176b79caff5ea304442714',
                'crc32' => '0abecb1d',
                'sha1' => '4c1a78c19bc152cd94df8b9c81285e950ecd495c'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002370.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452001',
                'size' => '7884',
                'md5' => '1281d43fb6f73e9f97c7085d28ea5c02',
                'crc32' => '736fb6e3',
                'sha1' => '7eaf252d5443104eedd9acb5764966e7b5cb0105'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002430.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452031',
                'size' => '8082',
                'md5' => '7029a522bd4f02f825d86987be2b2e29',
                'crc32' => 'a9fe1dce',
                'sha1' => '163c4ce309979f7d0b9c33daf17559892fb50c34'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002490.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452064',
                'size' => '7797',
                'md5' => '0faf61bf22d8fc18ed4ba47419e750d2',
                'crc32' => 'e8d44d2a',
                'sha1' => '66d236228b88ee7ce600cf70efcae797dfc876a6'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002550.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452092',
                'size' => '7530',
                'md5' => '3682bb2888213fe6ee522406fd46124a',
                'crc32' => 'f5512a32',
                'sha1' => 'd5c45b80cf241854c1fb7caa26b894b4ccffd333'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002610.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452119',
                'size' => '8211',
                'md5' => 'a84ba6f813faef974a98167f4161be64',
                'crc32' => '1f219f6b',
                'sha1' => '3b7b681fd2a4824c27f0bd755c940ea33b7f46a8'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002670.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452152',
                'size' => '8834',
                'md5' => 'dd31b5ff578e9fa12e0ad7129a500651',
                'crc32' => '576045ca',
                'sha1' => '9f7ec2f962bba93b37e9b4d3ef21fab33b6328fa'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002730.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452183',
                'size' => '8114',
                'md5' => 'dbcd8987c9315ed2a4563cfda70c2c8b',
                'crc32' => '7a0b8c83',
                'sha1' => '3ad13bebd6372d4eabae6e5b036e3755eec11039'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002790.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452210',
                'size' => '6765',
                'md5' => 'bb9db289a45369a98762ebfa3aecf351',
                'crc32' => '9c96ee7d',
                'sha1' => 'f7370b794ee34332bf504858a31e32e568d06ad8'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002850.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452230',
                'size' => '5396',
                'md5' => 'b4ecbee825cb067a75854d62898c8483',
                'crc32' => 'f909320d',
                'sha1' => 'ed7be9066f31c831f2548d13d043dec756a21b60'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002910.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452246',
                'size' => '5607',
                'md5' => 'b035f5f83d07f8c4ed1aff3877331f4b',
                'crc32' => '68fd4a93',
                'sha1' => '1e8dcb2bf8be564ff28d8f15d402e6b9f569b173'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_002970.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452272',
                'size' => '4465',
                'md5' => '7fa974d10b63629547abac4b20795bbf',
                'crc32' => '5373311e',
                'sha1' => 'c6ab42cef07a06af337b6c5926c7e2bd44bab763'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_003030.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452292',
                'size' => '7918',
                'md5' => '960cad667a523997bf3792ed786b7187',
                'crc32' => '969082bf',
                'sha1' => '24dd55448f22d3979fe59ea201d4f1ffeeac4ab0'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_003090.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452331',
                'size' => '5640',
                'md5' => '5c1113a6b297edfe8f6b2c74a16948e8',
                'crc32' => 'a78e20ba',
                'sha1' => '4f31ecb38e568a6accc625e822158c1305e416b3'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_003150.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452363',
                'size' => '7174',
                'md5' => 'aae62b432f3163d05d6329bcb167183b',
                'crc32' => '36338f84',
                'sha1' => 'a3a56abfb1b8d54f76675524b904123cc5c12949'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_003210.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452400',
                'size' => '7125',
                'md5' => '2976cf92a8ccf219d29a9e8034a21495',
                'crc32' => 'd9e2cb37',
                'sha1' => '78f1cdf5ebde818225daa20db0b3cc4c2e1749f2'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_003270.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452424',
                'size' => '7020',
                'md5' => '91ae9e89012ce1679243abff46edaadb',
                'crc32' => '57d2e2ec',
                'sha1' => '0e2232c336098ba9ab9501f1c432f25a49168ba7'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_003330.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452443',
                'size' => '6036',
                'md5' => '13789bc18f362629a1a52a608f0a61c8',
                'crc32' => 'edff0756',
                'sha1' => '75b807963832d60f4e38218ad114e5b16d0ea838'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_003390.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452467',
                'size' => '5054',
                'md5' => '2cf10cbe6830d1ee3c83bb08eb471a9c',
                'crc32' => '15cb42c1',
                'sha1' => 'a60cb92278404881c66c6a01998fae045028e1a5'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_003450.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452489',
                'size' => '7053',
                'md5' => '973fc1a89ce0ef15005a2b287a6d4e17',
                'crc32' => 'b43324a8',
                'sha1' => '3c5cb87aeea11bacfb88b510bee473b7561ecbce'
            ],
            '/dn2015-0220_vid.thumbs/dn2015-0220_003510.jpg' => [
                'source' => 'derivative',
                'format' => 'Thumbnail',
                'original' => 'dn2015-0220.mpeg',
                'mtime' => '1424452517',
                'size' => '6046',
                'md5' => '6248f0d6af501c1ec9a127bb0802a08e',
                'crc32' => 'a621da55',
                'sha1' => 'baf770c026701bbb3e288b6eadba29703aae87e0'
            ],
            '/dn2015-0220_vid_archive.torrent' => [
                'source' => 'original',
                'btih' => 'd3f9f4af56caa39e94b7f85ce7d7b9e722163341',
                'mtime' => '1542757137',
                'size' => '37836',
                'md5' => 'c861226dbe6e4b211c5290e5b4a1ba8d',
                'crc32' => 'd9aca1b6',
                'sha1' => '12875539f9104546176f32edfac2140004703c47',
                'format' => 'Archive BitTorrent'
            ],
            '/dn2015-0220_vid_files.xml' => [
                'source' => 'original',
                'format' => 'Metadata',
                'md5' => '745ea2f6dde93e4b70b1c0b238d4c0e2'
            ],
            '/dn2015-0220_vid_meta.xml' => [
                'source' => 'original',
                'mtime' => '1542757137',
                'size' => '1973',
                'format' => 'Metadata',
                'md5' => '6a144c80a58ab5f08c0ecffdb580954a',
                'crc32' => 'a0ce73ae',
                'sha1' => '478a1338b524d61776aebe9c0e8aca57a38a5dfc'
            ]
        ],
        'misc' => [
            'image' => 'https://ia802600.us.archive.org/20/items/dn2015-0220_vid/dn2015-0220.gif',
            'collection-title' => 'Democracy Now!'
        ],
        'item' => [
            'downloads' => 132,
            'month' => 2,
            'item_size' => 3667677269,
            'files_count' => 68,
            'item_count' => null,
            'collection_files_count' => null,
            'collection_size' => null
        ]
    ],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.org',
            '@type' => 'BreadcrumbList',
            'itemListElement' => [
                [
                    '@type' => 'ListItem',
                    'position' => 1,
                    'item' => [
                        '@id' => 'https://archive.org/details/movies',
                        'name' => 'Videos',
                        'image' => 'https://archive.org/services/img/movies'
                    ]
                ]
            ]
        ]
    ]
];
